@@ -21,5 +21,17 @@
 #
 
 # A trivial example
-def output(arg, kw="Universe"):
+import numpy as np
+import gzip, shutil
+
+def output(arg:str, kw:str="Universe") -> str:
     return(f"Hello {arg} and {kw}")
+
+def create_array(size:int) -> np.array:
+    return np.array(size)
+
+def gunzip(f_in:str, f_out:str) -> None:
+    with gzip.open(f_in, 'rb') as f:
+        with open(f_out, 'wb') as o:
+            shutil.copyfileobj(f, o)
+    return None
